@@ -2,6 +2,7 @@ import json
 import pickle
 import sys
 import io
+import os
 import logging
 import re  # NOQA
 import builtins  # NOQA
@@ -9,6 +10,18 @@ import datetime  # NOQA
 import decimal  # NOQA
 import ordered_set  # NOQA
 import collections  # NOQA
+try:
+    import yaml
+except ImportError:  # pragma: no cover.
+    yaml = None  # pragma: no cover.
+try:
+    import toml
+except ImportError:  # pragma: no cover.
+    toml = None  # pragma: no cover.
+try:
+    import clevercsv
+except ImportError:  # pragma: no cover.
+    clevercsv = None  # pragma: no cover.
 from copy import deepcopy
 from collections.abc import Mapping
 from deepdiff.helper import (strings, json_convertor_default, get_type, TEXT_VIEW)
@@ -22,11 +35,17 @@ except ImportError:  # pragma: no cover. Json pickle is getting deprecated.
     jsonpickle = None  # pragma: no cover. Json pickle is getting deprecated.
 
 
-MAX_HEADER_LENGTH = 256
+class UnsupportedFormatErr(TypeError):
+    pass
+
+
+CSV_HEADER_MAX_CHUNK_SIZE = 2048  # The chunk needs to be big enough that covers a couple of rows of data.
+
 
 MODULE_NOT_FOUND_MSG = 'DeepDiff Delta did not find {} in your modules. Please make sure it is already imported.'
 FORBIDDEN_MODULE_MSG = "Module '{}' is forbidden. You need to explicitly pass it by passing a safe_to_import parameter"
 DELTA_IGNORE_ORDER_NEEDS_REPETITION_REPORT = 'report_repetition must be set to True when ignore_order is True to create the delta object.'
+DELTA_ERROR_WHEN_GROUP_BY = 'Delta can not be made when group_by is used since the structure of data is modified from the original form.'
 
 SAFE_TO_IMPORT = {
     'builtins.range',
@@ -50,6 +69,7 @@ SAFE_TO_IMPORT = {
     'decimal.Decimal',
     'ordered_set.OrderedSet',
     'collections.namedtuple',
+    'collections.OrderedDict',
     'deepdiff.helper.OrderedDictPlus',
     're.Pattern',
 }
@@ -164,6 +184,9 @@ class SerializationMixin:
         was set to be True in the diff object.
 
         """
+        if self.group_by is not None:
+            raise ValueError(DELTA_ERROR_WHEN_GROUP_BY)
+
         result = DeltaResult(tree_results=self.tree, ignore_order=self.ignore_order)
         result.remove_empty_keys()
         if report_repetition_required and self.ignore_order and not self.report_repetition:
@@ -298,3 +321,102 @@ def pretty_print_diff(diff):
         type_t2=type_t2,
         val_t1=val_t1,
         val_t2=val_t2)
+
+
+def load_path_content(path, file_type=None):
+    """
+    Loads and deserializes the content of the path.
+    """
+    if file_type is None:
+        file_type = path.split('.')[-1]
+    if file_type == 'json':
+        with open(path, 'r') as the_file:
+            content = json.load(the_file)
+    elif file_type in {'yaml', '.yml'}:
+        if yaml is None:  # pragma: no cover.
+            raise ImportError('Pyyaml needs to be installed.')  # pragma: no cover.
+        with open(path, 'r') as the_file:
+            content = yaml.safe_load(the_file)
+    elif file_type == 'toml':
+        if toml is None:  # pragma: no cover.
+            raise ImportError('Toml needs to be installed.')  # pragma: no cover.
+        with open(path, 'r') as the_file:
+            content = toml.load(the_file)
+    elif file_type == 'pickle':
+        with open(path, 'rb') as the_file:
+            content = the_file.read()
+            content = pickle_load(content)
+    elif file_type in {'csv', 'tsv'}:
+        if clevercsv is None:  # pragma: no cover.
+            raise ImportError('CleverCSV needs to be installed.')  # pragma: no cover.
+        content = clevercsv.read_dicts(path)
+        logger.info(f"NOTE: CSV content was empty in {path}")
+
+        # Everything in csv is string but we try to automatically convert any numbers we find
+        for row in content:
+            for key, value in row.items():
+                value = value.strip()
+                for type_ in [int, float, complex]:
+                    try:
+                        value = type_(value)
+                    except Exception:
+                        pass
+                    else:
+                        row[key] = value
+                        break
+    else:
+        raise UnsupportedFormatErr(f'Only json, yaml, toml, csv, tsv and pickle are supported.\n'
+                                   f' The {file_type} extension is not known.')
+    return content
+
+
+def save_content_to_path(content, path, file_type=None, keep_backup=True):
+    """
+    Saves and serializes the content of the path.
+    """
+
+    backup_path = f"{path}.bak"
+    os.rename(path, backup_path)
+
+    try:
+        _save_content(
+            content=content, path=path,
+            file_type=file_type, keep_backup=keep_backup)
+    except Exception:
+        os.rename(backup_path, path)
+        raise
+    else:
+        if not keep_backup:
+            os.remove(backup_path)
+
+
+def _save_content(content, path, file_type, keep_backup=True):
+    if file_type == 'json':
+        with open(path, 'w') as the_file:
+            content = json.dump(content, the_file)
+    elif file_type in {'yaml', '.yml'}:
+        if yaml is None:  # pragma: no cover.
+            raise ImportError('Pyyaml needs to be installed.')  # pragma: no cover.
+        with open(path, 'w') as the_file:
+            content = yaml.safe_dump(content, stream=the_file)
+    elif file_type == 'toml':
+        if toml is None:  # pragma: no cover.
+            raise ImportError('Toml needs to be installed.')  # pragma: no cover.
+        with open(path, 'w') as the_file:
+            content = toml.dump(content, the_file)
+    elif file_type == 'pickle':
+        with open(path, 'wb') as the_file:
+            content = pickle_dump(content)
+            the_file.write(content)
+    elif file_type in {'csv', 'tsv'}:
+        if clevercsv is None:  # pragma: no cover.
+            raise ImportError('CleverCSV needs to be installed.')  # pragma: no cover.
+        with open(path, 'w', newline='') as csvfile:
+            fieldnames = list(content[0].keys())
+            writer = clevercsv.DictWriter(csvfile, fieldnames=fieldnames)
+            writer.writeheader()
+            writer.writerows(content)
+    else:
+        raise UnsupportedFormatErr('Only json, yaml, toml, csv, tsv and pickle are supported.\n'
+                                   f' The {file_type} extension is not known.')
+    return content
