@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+import os
 import json
 import sys
 import pytest
@@ -6,10 +7,12 @@ import datetime
 from pickle import UnpicklingError
 from decimal import Decimal
 from deepdiff import DeepDiff
-from deepdiff.helper import py3_5, pypy3
+from deepdiff.helper import pypy3
 from deepdiff.serialization import (
     pickle_load, pickle_dump, ForbiddenModule, ModuleNotFoundError,
-    MODULE_NOT_FOUND_MSG, FORBIDDEN_MODULE_MSG, pretty_print_diff)
+    MODULE_NOT_FOUND_MSG, FORBIDDEN_MODULE_MSG, pretty_print_diff,
+    load_path_content, UnsupportedFormatErr)
+from conftest import FIXTURES_DIR
 from ordered_set import OrderedSet
 from tests import PicklableClass
 
@@ -29,7 +32,6 @@ class TestSerialization:
         jsoned = ddiff.to_json()
         assert "world" in jsoned
 
-    @pytest.mark.skipif(py3_5, reason='json pickle does not work well with py 3.5')
     def test_deserialization(self):
         ddiff = DeepDiff(t1, t2)
         jsoned = ddiff.to_json_pickle()
@@ -43,7 +45,6 @@ class TestSerialization:
         jsoned = ddiff.to_json()
         assert "world" in jsoned
 
-    @pytest.mark.skipif(py3_5, reason='json pickle does not work well with py 3.5')
     def test_deserialization_tree(self):
         ddiff = DeepDiff(t1, t2, view='tree')
         jsoned = ddiff.to_json_pickle()
@@ -92,6 +93,27 @@ class TestSerialization:
         assert expected == ddiff.to_dict()
 
 
+@pytest.mark.skipif(pypy3, reason='clevercsv is not supported in pypy3')
+class TestLoadContet:
+
+    @pytest.mark.parametrize('path1, validate', [
+        ('t1.json', lambda x: x[0]['key1'] == 'value1'),
+        ('t1.yaml', lambda x: x[0][0] == 'name'),
+        ('t1.toml', lambda x: x['servers']['alpha']['ip'] == '10.0.0.1'),
+        ('t1.csv', lambda x: x[0]['last_name'] == 'Nobody'),
+        ('t1.pickle', lambda x: x[1] == 1),
+    ])
+    def test_load_path_content(self, path1, validate):
+        path = os.path.join(FIXTURES_DIR, path1)
+        result = load_path_content(path)
+        assert validate(result)
+
+    def test_load_path_content_when_unsupported_format(self):
+        path = os.path.join(FIXTURES_DIR, 't1.unsupported')
+        with pytest.raises(UnsupportedFormatErr):
+            load_path_content(path)
+
+
 class TestPickling:
 
     def test_serialize(self):
